# `ahe`
<!--
[![PyPI](https://img.shields.io/pypi/v/ahe.svg?logo=pypi&logoColor=white&label=PyPI)](https://pypi.org/project/ahe/)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/ahe.svg?logo=condaforge&logoColor=white)](https://anaconda.org/conda-forge/ahe)
-->
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)


A minimalist Python library for Adaptive Histogram Equalization,
combining the expressiveness of a user-friendly Python interface with the raw power of
a low-level implementation.

## Development status

> [!WARNING]
> pre-alpha software

## Installation

> [!IMPORTANT]
> TODO

## Usage

> [!IMPORTANT]
> TODO

## Migrating from `scikit-image`
### Why
> [!IMPORTANT]
> TODO

- a much smaller package
- future portability (abi3 wheels)
- better performance
- no deps beyond numpy
- improved guarantees on transformation invariants

### How
> [!IMPORTANT]
> TODO
